#!/usr/bin/env python3
import os
import shutil
import subprocess
import sys
import typing
from pathlib import Path


def usage():
    print(f"usage: {sys.argv[0]} src output_dir", file=sys.stderr)
    sys.exit(1)


def main():
    if len(sys.argv) < 3:
        usage()

    src_dir = sys.argv[1]
    output_dir = sys.argv[2]

    path = typing.cast(str, os.environ.get("PATH"))
    # add bin to the PATH
    os.environ["PATH"] = os.path.join(src_dir, "bin") + ":" + path

    # Change to the source directory
    os.chdir(src_dir)

    # Create the output directory if it doesn't exist
    os.makedirs(output_dir, exist_ok=True)

    # Remove contents of the output directory
    for item in os.listdir(output_dir):
        item_path = os.path.join(output_dir, item)
        if os.path.isdir(item_path):
            shutil.rmtree(item_path)
        else:
            os.remove(item_path)

    # Process HTML files
    for p in Path("src").rglob("*.html"):
        rel_path = os.path.relpath(p, "./src")
        output_file_path = os.path.join(output_dir, rel_path)
        output_dir_path = os.path.dirname(output_file_path)
        os.makedirs(output_dir_path, exist_ok=True)
        print(f"Making {rel_path}")
        if p.match("blog/*.html"):
            subprocess.run(
                ["pp", "./templates/default.html", p, "./templates/comment.html"],
                stdout=open(output_file_path, "w"),
            )
        else:
            subprocess.run(
                ["pp", "./templates/default.html", p],
                stdout=open(output_file_path, "w"),
            )

    # Copy stylesheet
    print("Copying stylesheet")
    shutil.copy("./templates/style.css", output_dir)

    # Copy assets
    print("Copying assets")
    shutil.copytree("./assets", os.path.join(output_dir, "assets"))


if __name__ == "__main__":
    main()
